# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetContactCustomAttrListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："AQD9/Rn9eij9Pm39ED40/RYU5lvOM4s6zgbeeNNaWd%2BVKwAsoreeRWk0J2noGvJy"


@attr.s
class GetContactCustomAttrListRespItemI18nName(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言版本
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段名


@attr.s
class GetContactCustomAttrListRespItemOptionsOption(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举类型选项id
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举选项值，当option_type为`TEXT`为文本值，当option_type为`PICTURE`时为图片链接
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 名称，仅option_type为PICTURE时有效


@attr.s
class GetContactCustomAttrListRespItemOptions(object):
    default_option_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认选项id
    option_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 选项类型, 可选值有: `TEXT`：文本选项, `PICTURE`：图片选项
    options: typing.List[GetContactCustomAttrListRespItemOptionsOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 选项列表


@attr.s
class GetContactCustomAttrListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段id
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段类型，可选值有:, `TEXT`：纯文本，用于纯文本描述人员，如备注, `HREF`：静态 URL，用于人员 Profile 跳转链接, `ENUMERATION`：枚举，用于结构化描述人员，如民族, `GENERIC_USER`：用户，用于描述人和人关系，如 HRBP, `PICTURE_ENUM`：枚举图片，以结构化的图片描述人员，如在人员 Profile 展示荣誉徽章
    options: GetContactCustomAttrListRespItemOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 选项定义，当type为`ENUMERATION`或者`PICTURE_ENUM`时此项有值，列举所有可选项
    i18n_name: GetContactCustomAttrListRespItemI18nName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 自定义字段的字段名称


@attr.s
class GetContactCustomAttrListResp(object):
    items: typing.List[GetContactCustomAttrListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段定义
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_contact_custom_attr_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetContactCustomAttrListResp,
        scope="Contact",
        api="GetContactCustomAttrList",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v3/custom_attrs",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class IsApplicationUserAdminReq(object):
    open_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户 open_id，open_id 和 employee_id 两个参数必须包含其一，若同时传入取 open_id
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户 employee_id（同通讯录 v3 版本中的 user_id），open_id 和 employee_id 两个参数必须包含其一，若同时传入取 open_id


@attr.s
class IsApplicationUserAdminResp(object):
    is_app_admin: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 用户是否为管理员，true 为是，false 为否


def _gen_is_application_user_admin_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=IsApplicationUserAdminResp,
        scope="Application",
        api="IsApplicationUserAdmin",
        method="GET",
        url="https://open.feishu.cn/open-apis/application/v3/is_user_admin",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserTaskRemedyReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserTaskRemedyReq(object):
    employee_type: GetAttendanceUserTaskRemedyReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserTaskRemedyReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值：“employee_id”
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # employee_no 或 employee_id 列表
    check_time_from: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询的起始时间，精确到秒的时间戳
    check_time_to: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询的结束时间，精确到秒的时间戳


@attr.s
class GetAttendanceUserTaskRemedyRespUserRemedy(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 补卡状态，可用值：【0（pending），2（已通过），3（已取消），4（通过后撤销）】
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 补卡原因
    time: str = attr.ib(default="", metadata={"req_type": "json"})  # 补卡时间，精确到秒的时间戳
    time_zone: str = attr.ib(default="", metadata={"req_type": "json"})  # 补卡时的考勤组时区
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 补卡发起时间，精确到秒的时间戳
    update_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 补卡状态更新时间，精确到秒的时间戳


@attr.s
class GetAttendanceUserTaskRemedyResp(object):
    user_remedys: typing.List[GetAttendanceUserTaskRemedyRespUserRemedy] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 补卡记录列表


def _gen_get_attendance_user_task_remedy_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserTaskRemedyResp,
        scope="Attendance",
        api="GetAttendanceUserTaskRemedy",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_task_remedys/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBitableFieldListReq(object):
    view_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 视图 ID, 示例值："vewOVMEXPF"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："fldwJ4YrtB"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # table id, 示例值："tblsRc9GRRXKqhvW"


@attr.s
class GetBitableFieldListRespItemPropertyOption(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项名
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项id


@attr.s
class GetBitableFieldListRespItemProperty(object):
    options: typing.List[GetBitableFieldListRespItemPropertyOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 单选/多选字段的选项信息
    formatter: str = attr.ib(default="", metadata={"req_type": "json"})  # 数字字段的数字显示格式
    date_format: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期格式
    time_format: str = attr.ib(default="", metadata={"req_type": "json"})  # 时间格式
    auto_fill: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否自动填入创建时间
    multiple: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 多选标记
    table_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 关联字段中关联表的id
    view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 关联字段中关联表的视图id
    fields: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联字段要展示的字段


@attr.s
class GetBitableFieldListRespItem(object):
    field_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 多维表格字段 id
    field_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 多维表格字段名
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 多维表格字段类型
    property: GetBitableFieldListRespItemProperty = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段属性, 具体参考: [Property说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/bitable/development-guide/bitable-structure#b286b4ee)


@attr.s
class GetBitableFieldListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetBitableFieldListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 字段信息


def _gen_get_bitable_field_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBitableFieldListResp,
        scope="Bitable",
        api="GetBitableFieldList",
        method="GET",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables/:table_id/fields",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetUserReqDepartmentIDType(object):
    pass


@attr.s
class GetUserReqUserIDType(object):
    pass


@attr.s
class GetUserReq(object):
    user_id_type: GetUserReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    department_id_type: GetUserReqDepartmentIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 此次调用中使用的部门ID的类型, 示例值："open_department_id", 可选值有: `department_id`：以自定义department_id来标识部门, `open_department_id`：以open_department_id来标识部门, 默认值: `open_department_id`
    user_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 用户ID，需要与查询参数中的user_id_type类型保持一致。, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"


@attr.s
class GetUserRespUserCustomAttrValueGenericUser(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的user_id
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 用户类型    1：用户


@attr.s
class GetUserRespUserCustomAttrValue(object):
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段类型为 TEXT 时该参数定义字段值，字段类型为 HREF 时该参数定义网页标题
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段类型为 HREF 时，该参数定义默认 URL
    pc_url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段类型为 HREF 时，该参数定义PC端 URL
    option_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项值
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    picture_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 图片链接
    generic_user: GetUserRespUserCustomAttrValueGenericUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段类型为 GENERIC_USER 时，该参数定义引用人员


@attr.s
class GetUserRespUserCustomAttr(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段类型   , `TEXT`, `HREF`, `ENUMERATION`, `PICTURE_ENUM`, `GENERIC_USER`
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID
    value: GetUserRespUserCustomAttrValue = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 自定义字段取值


@attr.s
class GetUserRespUserOrder(object):
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 排序信息对应的部门ID
    user_order: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户在其直属部门内的排序，数值越大，排序越靠前
    department_order: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户所属的多个部门间的排序，数值越大，排序越靠前


@attr.s
class GetUserRespUserStatus(object):
    is_frozen: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否暂停
    is_resigned: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否离职
    is_activated: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否激活


@attr.s
class GetUserRespUserAvatar(object):
    avatar_72: str = attr.ib(default="", metadata={"req_type": "json"})  # 72*72像素头像链接
    avatar_240: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 240*240像素头像链接
    avatar_640: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 640*640像素头像链接
    avatar_origin: str = attr.ib(default="", metadata={"req_type": "json"})  # 原始头像链接


@attr.s
class GetUserRespUser(object):
    union_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的union_id
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内用户的唯一标识, 字段权限要求:  获取用户 user ID
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的open_id
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户名, 最小长度：`1` 字符,**字段权限要求（满足任一）**：, 获取用户基本信息, 以应用身份访问通讯录（历史版本）
    en_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 英文名,**字段权限要求（满足任一）**：, 获取用户基本信息, 以应用身份访问通讯录（历史版本）
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 邮箱, 字段权限要求:  获取用户邮箱信息
    mobile: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 手机号, 字段权限要求:  获取用户手机号
    mobile_visible: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 手机号码可见性，true 为可见，false 为不可见，目前默认为 true。不可见时，组织员工将无法查看该员工的手机号码
    gender: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 性别, 可选值有: `0`：保密, `1`：男, `2`：女,**字段权限要求（满足任一）**：, 获取用户性别, 以应用身份访问通讯录（历史版本）
    avatar: GetUserRespUserAvatar = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户头像信息,**字段权限要求（满足任一）**：, 获取用户基本信息, 以应用身份访问通讯录（历史版本）
    status: GetUserRespUserStatus = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户状态,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    department_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户所属部门的ID列表,**字段权限要求（满足任一）**：, 获取用户组织架构信息, 以应用身份访问通讯录（历史版本）
    leader_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的直接主管的用户ID,**字段权限要求（满足任一）**：, 获取用户组织架构信息, 以应用身份访问通讯录（历史版本）
    city: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 城市,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    country: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 国家或地区,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    work_station: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 工位,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    join_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 入职时间,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    is_tenant_manager: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否是租户管理员,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    employee_no: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 工号,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    employee_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 员工类型，可选值有：, 1：正式员工, 2：实习生, 3：外包, 4：劳务, 5：顾问   ,同时可读取到自定义员工类型的 int 值，可通过下方接口获取到该租户的自定义员工类型的名称   ,[获取人员类型](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/contact-v3/employee_type_enum/list),**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    orders: typing.List[GetUserRespUserOrder] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户排序信息,**字段权限要求（满足任一）**：, 获取用户组织架构信息, 以应用身份访问通讯录（历史版本）
    custom_attrs: typing.List[GetUserRespUserCustomAttr] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    enterprise_email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 企业邮箱，请先确保已在管理后台启用飞书邮箱服务,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）
    job_title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 职务,**字段权限要求（满足任一）**：, 获取用户雇佣信息, 以应用身份访问通讯录（历史版本）


@attr.s
class GetUserResp(object):
    user: GetUserRespUser = attr.ib(default=None, metadata={"req_type": "json"})  # 用户信息


def _gen_get_user_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetUserResp,
        scope="Contact",
        api="GetUser",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v3/users/:user_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_attendance_file_download import (
    DownloadAttendanceFileReq,
    DownloadAttendanceFileResp,
    _gen_download_attendance_file_req,
)
from pylark.api_service_attendance_file_upload import (
    UploadAttendanceFileReq,
    UploadAttendanceFileResp,
    _gen_upload_attendance_file_req,
)
from pylark.api_service_attendance_user_settings_query import (
    QueryAttendanceUserSettingsReq,
    QueryAttendanceUserSettingsResp,
    _gen_query_attendance_user_settings_req,
)
from pylark.api_service_attendance_user_settings_update import (
    UpdateAttendanceUserSettingsReq,
    UpdateAttendanceUserSettingsResp,
    _gen_update_attendance_user_settings_req,
)
from pylark.api_service_attendance_group_create_update import (
    CreateUpdateAttendanceGroupReq,
    CreateUpdateAttendanceGroupResp,
    _gen_create_update_attendance_group_req,
)
from pylark.api_service_attendance_group_delete import (
    DeleteAttendanceGroupReq,
    DeleteAttendanceGroupResp,
    _gen_delete_attendance_group_req,
)
from pylark.api_service_attendance_group_get import (
    GetAttendanceGroupReq,
    GetAttendanceGroupResp,
    _gen_get_attendance_group_req,
)
from pylark.api_service_attendance_shift_create import (
    CreateAttendanceShiftReq,
    CreateAttendanceShiftResp,
    _gen_create_attendance_shift_req,
)
from pylark.api_service_attendance_shift_delete import (
    DeleteAttendanceShiftReq,
    DeleteAttendanceShiftResp,
    _gen_delete_attendance_shift_req,
)
from pylark.api_service_attendance_shift_get_by_id import (
    GetAttendanceShiftByIDReq,
    GetAttendanceShiftByIDResp,
    _gen_get_attendance_shift_by_id_req,
)
from pylark.api_service_attendance_shift_get_by_name import (
    GetAttendanceShiftByNameReq,
    GetAttendanceShiftByNameResp,
    _gen_get_attendance_shift_by_name_req,
)
from pylark.api_service_attendance_statistics_data_get import (
    GetAttendanceStatisticsDataReq,
    GetAttendanceStatisticsDataResp,
    _gen_get_attendance_statistics_data_req,
)
from pylark.api_service_attendance_statistics_header_get import (
    GetAttendanceStatisticsHeaderReq,
    GetAttendanceStatisticsHeaderResp,
    _gen_get_attendance_statistics_header_req,
)
from pylark.api_service_attendance_user_statistics_settings_update import (
    UpdateAttendanceUserStatisticsSettingsReq,
    UpdateAttendanceUserStatisticsSettingsResp,
    _gen_update_attendance_user_statistics_settings_req,
)
from pylark.api_service_attendance_user_statistics_settings_get import (
    GetAttendanceUserStatisticsSettingsReq,
    GetAttendanceUserStatisticsSettingsResp,
    _gen_get_attendance_user_statistics_settings_req,
)
from pylark.api_service_attendance_user_daily_shift_get import (
    GetAttendanceUserDailyShiftReq,
    GetAttendanceUserDailyShiftResp,
    _gen_get_attendance_user_daily_shift_req,
)
from pylark.api_service_attendance_user_task_get import (
    GetAttendanceUserTaskReq,
    GetAttendanceUserTaskResp,
    _gen_get_attendance_user_task_req,
)
from pylark.api_service_attendance_user_flow_get import (
    GetAttendanceUserFlowReq,
    GetAttendanceUserFlowResp,
    _gen_get_attendance_user_flow_req,
)
from pylark.api_service_attendance_user_flow_batch_get import (
    BatchGetAttendanceUserFlowReq,
    BatchGetAttendanceUserFlowResp,
    _gen_batch_get_attendance_user_flow_req,
)
from pylark.api_service_attendance_user_flow_batch_create import (
    BatchCreateAttendanceUserFlowReq,
    BatchCreateAttendanceUserFlowResp,
    _gen_batch_create_attendance_user_flow_req,
)
from pylark.api_service_attendance_user_task_remedy_get import (
    GetAttendanceUserTaskRemedyReq,
    GetAttendanceUserTaskRemedyResp,
    _gen_get_attendance_user_task_remedy_req,
)
from pylark.api_service_attendance_user_daily_shift_create_update import (
    CreateUpdateAttendanceUserDailyShiftReq,
    CreateUpdateAttendanceUserDailyShiftResp,
    _gen_create_update_attendance_user_daily_shift_req,
)
from pylark.api_service_attendance_user_approval_get import (
    GetAttendanceUserApprovalReq,
    GetAttendanceUserApprovalResp,
    _gen_get_attendance_user_approval_req,
)
from pylark.api_service_attendance_user_approval_create import (
    CreateAttendanceUserApprovalReq,
    CreateAttendanceUserApprovalResp,
    _gen_create_attendance_user_approval_req,
)
from pylark.api_service_attendance_user_allowed_remedy_get import (
    GetAttendanceUserAllowedRemedyReq,
    GetAttendanceUserAllowedRemedyResp,
    _gen_get_attendance_user_allowed_remedy_req,
)
from pylark.api_service_attendance_remedy_approval_init import (
    InitAttendanceRemedyApprovalReq,
    InitAttendanceRemedyApprovalResp,
    _gen_init_attendance_remedy_approval_req,
)
from pylark.api_service_attendance_remedy_approval_update import (
    UpdateAttendanceRemedyApprovalReq,
    UpdateAttendanceRemedyApprovalResp,
    _gen_update_attendance_remedy_approval_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkAttendanceService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def download_attendance_file(
        self, request: DownloadAttendanceFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadAttendanceFileResp, Response]:
        return self.cli.raw_request(_gen_download_attendance_file_req(request, options))

    def upload_attendance_file(
        self, request: UploadAttendanceFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadAttendanceFileResp, Response]:
        return self.cli.raw_request(_gen_upload_attendance_file_req(request, options))

    def query_attendance_user_settings(
        self, request: QueryAttendanceUserSettingsReq, options: typing.List[str] = None
    ) -> typing.Tuple[QueryAttendanceUserSettingsResp, Response]:
        return self.cli.raw_request(
            _gen_query_attendance_user_settings_req(request, options)
        )

    def update_attendance_user_settings(
        self, request: UpdateAttendanceUserSettingsReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateAttendanceUserSettingsResp, Response]:
        return self.cli.raw_request(
            _gen_update_attendance_user_settings_req(request, options)
        )

    def create_update_attendance_group(
        self, request: CreateUpdateAttendanceGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateUpdateAttendanceGroupResp, Response]:
        return self.cli.raw_request(
            _gen_create_update_attendance_group_req(request, options)
        )

    def delete_attendance_group(
        self, request: DeleteAttendanceGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteAttendanceGroupResp, Response]:
        return self.cli.raw_request(_gen_delete_attendance_group_req(request, options))

    def get_attendance_group(
        self, request: GetAttendanceGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceGroupResp, Response]:
        return self.cli.raw_request(_gen_get_attendance_group_req(request, options))

    def create_attendance_shift(
        self, request: CreateAttendanceShiftReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateAttendanceShiftResp, Response]:
        return self.cli.raw_request(_gen_create_attendance_shift_req(request, options))

    def delete_attendance_shift(
        self, request: DeleteAttendanceShiftReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteAttendanceShiftResp, Response]:
        return self.cli.raw_request(_gen_delete_attendance_shift_req(request, options))

    def get_attendance_shift_by_id(
        self, request: GetAttendanceShiftByIDReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceShiftByIDResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_shift_by_id_req(request, options)
        )

    def get_attendance_shift_by_name(
        self, request: GetAttendanceShiftByNameReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceShiftByNameResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_shift_by_name_req(request, options)
        )

    def get_attendance_statistics_data(
        self, request: GetAttendanceStatisticsDataReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceStatisticsDataResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_statistics_data_req(request, options)
        )

    def get_attendance_statistics_header(
        self,
        request: GetAttendanceStatisticsHeaderReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetAttendanceStatisticsHeaderResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_statistics_header_req(request, options)
        )

    def update_attendance_user_statistics_settings(
        self,
        request: UpdateAttendanceUserStatisticsSettingsReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateAttendanceUserStatisticsSettingsResp, Response]:
        return self.cli.raw_request(
            _gen_update_attendance_user_statistics_settings_req(request, options)
        )

    def get_attendance_user_statistics_settings(
        self,
        request: GetAttendanceUserStatisticsSettingsReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetAttendanceUserStatisticsSettingsResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_user_statistics_settings_req(request, options)
        )

    def get_attendance_user_daily_shift(
        self, request: GetAttendanceUserDailyShiftReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceUserDailyShiftResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_user_daily_shift_req(request, options)
        )

    def get_attendance_user_task(
        self, request: GetAttendanceUserTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceUserTaskResp, Response]:
        return self.cli.raw_request(_gen_get_attendance_user_task_req(request, options))

    def get_attendance_user_flow(
        self, request: GetAttendanceUserFlowReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceUserFlowResp, Response]:
        return self.cli.raw_request(_gen_get_attendance_user_flow_req(request, options))

    def batch_get_attendance_user_flow(
        self, request: BatchGetAttendanceUserFlowReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetAttendanceUserFlowResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_attendance_user_flow_req(request, options)
        )

    def batch_create_attendance_user_flow(
        self,
        request: BatchCreateAttendanceUserFlowReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[BatchCreateAttendanceUserFlowResp, Response]:
        return self.cli.raw_request(
            _gen_batch_create_attendance_user_flow_req(request, options)
        )

    def get_attendance_user_task_remedy(
        self, request: GetAttendanceUserTaskRemedyReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceUserTaskRemedyResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_user_task_remedy_req(request, options)
        )

    def create_update_attendance_user_daily_shift(
        self,
        request: CreateUpdateAttendanceUserDailyShiftReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateUpdateAttendanceUserDailyShiftResp, Response]:
        return self.cli.raw_request(
            _gen_create_update_attendance_user_daily_shift_req(request, options)
        )

    def get_attendance_user_approval(
        self, request: GetAttendanceUserApprovalReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAttendanceUserApprovalResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_user_approval_req(request, options)
        )

    def create_attendance_user_approval(
        self, request: CreateAttendanceUserApprovalReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateAttendanceUserApprovalResp, Response]:
        return self.cli.raw_request(
            _gen_create_attendance_user_approval_req(request, options)
        )

    def get_attendance_user_allowed_remedy(
        self,
        request: GetAttendanceUserAllowedRemedyReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetAttendanceUserAllowedRemedyResp, Response]:
        return self.cli.raw_request(
            _gen_get_attendance_user_allowed_remedy_req(request, options)
        )

    def init_attendance_remedy_approval(
        self, request: InitAttendanceRemedyApprovalReq, options: typing.List[str] = None
    ) -> typing.Tuple[InitAttendanceRemedyApprovalResp, Response]:
        return self.cli.raw_request(
            _gen_init_attendance_remedy_approval_req(request, options)
        )

    def update_attendance_remedy_approval(
        self,
        request: UpdateAttendanceRemedyApprovalReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateAttendanceRemedyApprovalResp, Response]:
        return self.cli.raw_request(
            _gen_update_attendance_remedy_approval_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateSheetReq(object):
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 表格标题, 示例值："title"
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件夹token, 示例值："fldcnMsNb*****hIW9IjG1LVswg"


@attr.s
class CreateSheetRespSpreadsheet(object):
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 表格标题
    folder_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹token
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档url
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 表格token


@attr.s
class CreateSheetResp(object):
    spreadsheet: CreateSheetRespSpreadsheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 表格


def _gen_create_sheet_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateSheetResp,
        scope="Drive",
        api="CreateSheet",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class AddChatMemberReqMemberIDType(object):
    pass


@attr.s
class AddChatMemberReq(object):
    member_id_type: AddChatMemberReqMemberIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 进群成员 id 类型 open_id/user_id/union_id/app_id, 示例值："user_id", 可选值有: `user_id`：以 user_id 来识别成员, `union_id`：以 union_id 来识别成员, `open_id`：以 open_id 来识别成员, `app_id`：以 app_id 来识别成员
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID，可以调用接口 [搜索对用户或机器人可见的群列表](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat/search) 获取chat_id, 示例值："oc_a0553eda9014c201e6969b478895c230"
    id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 成员列表


@attr.s
class AddChatMemberResp(object):
    invalid_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 无效成员列表


def _gen_add_chat_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=AddChatMemberResp,
        scope="Chat",
        api="AddChatMember",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/members",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetACSAccessRecordListReqUserIDType(object):
    pass


@attr.s
class GetACSAccessRecordListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：100, 最大值：`500`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："AQD9/Rn9eij9Pm39ED40/dk53s4Ebp882DYfFaPFbz00L4CMZJrqGdzNyc8BcZtDbwVUvRmQTvyMYicnGWrde9X56TgdBuS+JKiSIkdexPw="
    from_: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 记录开始时间，单位秒, 示例值：1624520521
    to: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 记录结束时间，单位秒，,时间跨度不能超过30天, 示例值：1624520521
    device_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 门禁设备 ID, 示例值："7091146989218002577"
    user_id_type: GetACSAccessRecordListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid


@attr.s
class GetACSAccessRecordListRespItem(object):
    access_record_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 门禁记录 ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 门禁记录所属用户 ID
    device_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 门禁设备 ID
    is_clock_in: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否是打卡
    access_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 访问时间，单位秒
    access_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 识别方式, 可选值有: `FA`：人脸识别方式
    access_data: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 识别相关数据，根据 access_type 不同，取值不同
    is_door_open: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否开门


@attr.s
class GetACSAccessRecordListResp(object):
    items: typing.List[GetACSAccessRecordListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # -
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_acs_access_record_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetACSAccessRecordListResp,
        scope="ACS",
        api="GetACSAccessRecordList",
        method="GET",
        url="https://open.feishu.cn/open-apis/acs/v1/access_records",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetCalendarEventAttendeeListReqUserIDType(object):
    pass


@attr.s
class GetCalendarEventAttendeeListReq(object):
    user_id_type: GetCalendarEventAttendeeListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："780TRhwXXXXX"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历 ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    event_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日程 ID, 示例值："xxxxxxxxx_0"


@attr.s
class GetCalendarEventAttendeeListRespItemChatMember(object):
    rsvp_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人RSVP状态, 可选值有: `needs_action`：参与人尚未回复状态，或表示会议室预约中, `accept`：参与人回复接受，或表示会议室预约成功, `tentative`：参与人回复待定, `decline`：参与人回复拒绝，或表示会议室预约失败, `removed`：参与人或会议室已经从日程中被移除
    is_optional: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为「可选参加」, 默认值: `false`
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人名称
    is_organizer: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为日程组织者
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为外部参与人


@attr.s
class GetCalendarEventAttendeeListRespItemType(object):
    pass


@attr.s
class GetCalendarEventAttendeeListRespItem(object):
    type: GetCalendarEventAttendeeListRespItemType = attr.ib(
        factory=lambda: GetCalendarEventAttendeeListRespItemType(),
        metadata={"req_type": "json"},
    )  # 参与人类型, 可选值有: `user`：用户, `chat`：群组, `resource`：会议室, `third_party`：邮箱
    attendee_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人ID
    rsvp_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人RSVP状态, 可选值有: `needs_action`：参与人尚未回复状态，或表示会议室预约中, `accept`：参与人回复接受，或表示会议室预约成功, `tentative`：参与人回复待定, `decline`：参与人回复拒绝，或表示会议室预约失败, `removed`：参与人或会议室已经从日程中被移除
    is_optional: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为「可选参加」，无法编辑群参与人的此字段, 默认值: `false`
    is_organizer: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为日程组织者
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为外部参与人；外部参与人不支持编辑
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人名称
    chat_members: typing.List[GetCalendarEventAttendeeListRespItemChatMember] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 群中的群成员，当type为Chat时有效；群成员不支持编辑
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人的用户id，依赖于user_id_type返回对应的取值，当is_external为true时，此字段只会返回open_id或者union_id
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # chat类型参与人的群组chat_id
    room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # resource类型参与人的会议室room_id
    third_party_email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # third_party类型参与人的邮箱


@attr.s
class GetCalendarEventAttendeeListResp(object):
    items: typing.List[GetCalendarEventAttendeeListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 日程的参与者列表
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token


def _gen_get_calendar_event_attendee_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetCalendarEventAttendeeListResp,
        scope="Calendar",
        api="GetCalendarEventAttendeeList",
        method="GET",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/events/:event_id/attendees",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserDailyShiftReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserDailyShiftReq(object):
    employee_type: GetAttendanceUserDailyShiftReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserDailyShiftReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_ids 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值：“employee_id”
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # employee_no 或 employee_id 列表
    check_date_from: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询的起始工作日
    check_date_to: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询的结束工作日


@attr.s
class GetAttendanceUserDailyShiftRespUserDailyShift(object):
    group_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组 ID
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID，休息为 0
    month: int = attr.ib(default=0, metadata={"req_type": "json"})  # 月份
    employee_no: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户
    day_no: int = attr.ib(default=0, metadata={"req_type": "json"})  # 日期


@attr.s
class GetAttendanceUserDailyShiftResp(object):
    user_daily_shifts: typing.List[
        GetAttendanceUserDailyShiftRespUserDailyShift
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 班表信息列表


def _gen_get_attendance_user_daily_shift_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserDailyShiftResp,
        scope="Attendance",
        api="GetAttendanceUserDailyShift",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_daily_shifts/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateTaskReminderReq(object):
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："83912691-2e43-47fc-94a4-d512e03984fa"
    relative_fire_minute: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 相对于截止时间的提醒时间（如提前 30 分钟，截止时间后 30 分钟，则为 -30）, 示例值：30


@attr.s
class CreateTaskReminderRespReminder(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 提醒时间设置的 ID（在删除时候需要使用这个）
    relative_fire_minute: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 相对于截止时间的提醒时间（如提前 30 分钟，截止时间后 30 分钟，则为 -30）


@attr.s
class CreateTaskReminderResp(object):
    reminder: CreateTaskReminderRespReminder = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 返回创建成功的提醒时间


def _gen_create_task_reminder_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateTaskReminderResp,
        scope="Task",
        api="CreateTaskReminder",
        method="POST",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/reminders",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateAttendanceRemedyApprovalReq(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 ID
    approval_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批类型，leave：请假，out：外出，overtime：加班，trip：出差，remedy：补卡
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 审批状态，1：不通过，2：通过，4：撤销


@attr.s
class UpdateAttendanceRemedyApprovalRespApprovalInfo(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 ID
    approval_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批类型，leave：请假，out：外出，overtime：加班，trip：出差，remedy：补卡
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 审批状态，1：不通过，2：通过，4：已撤销


@attr.s
class UpdateAttendanceRemedyApprovalResp(object):
    approval_info: UpdateAttendanceRemedyApprovalRespApprovalInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


def _gen_update_attendance_remedy_approval_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateAttendanceRemedyApprovalResp,
        scope="Attendance",
        api="UpdateAttendanceRemedyApproval",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/approval_infos/process",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateUpdateAttendanceGroupReqGroupNoNeedPunchSpecialDay(object):
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡日期，格式 20190101
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID


@attr.s
class CreateUpdateAttendanceGroupReqGroupNeedPunchSpecialDay(object):
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡日期，格式 20190101
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID


@attr.s
class CreateUpdateAttendanceGroupReqGroupFreePunchCfg(object):
    free_start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自由班制的打卡开始时间
    free_end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自由班制的打卡结束时间
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡时间，格式 1111100
    work_day_no_punch_as_lack: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作日不打卡是否记为缺卡


@attr.s
class CreateUpdateAttendanceGroupReqGroupLocationLongitude(object):
    pass


@attr.s
class CreateUpdateAttendanceGroupReqGroupLocationLatitude(object):
    pass


@attr.s
class CreateUpdateAttendanceGroupReqGroupLocation(object):
    location_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址 ID
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址名称，必选字段
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型，1：GPS，2：Wifi，8：IP
    latitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 地址纬度
    longitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 地址经度
    ssid: str = attr.ib(default="", metadata={"req_type": "json"})  # Wi-Fi 名称
    bssid: str = attr.ib(default="", metadata={"req_type": "json"})  # Wi-Fi 的 MAC 地址
    map_type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 地图类型，1：高德, 2：谷歌
    address: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址名称
    ip: str = attr.ib(default="", metadata={"req_type": "json"})  # IP 地址
    feature: str = attr.ib(default="", metadata={"req_type": "json"})  # 额外信息，例如运营商信息
    gps_range: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # GPS 打卡的有效范围（默认300m）


@attr.s
class CreateUpdateAttendanceGroupReqGroupMachine(object):
    machine_sn: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤机序列号
    machine_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤机名称


@attr.s
class CreateUpdateAttendanceGroupReqGroup(object):
    group_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 考勤组的 ID, 需要从获取用户打卡结果的接口中获取 groupId
    group_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组名称
    time_zone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 时区，可参考时区列表 https://www.zeitverschiebung.net/cn/all-time-zones.html
    bind_dept_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 绑定的部门 ID
    except_dept_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 排除的部门 ID
    bind_user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 绑定的用户 ID
    except_user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 排除的用户 ID
    group_leader_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 考勤负责人 ID 列表，需至少存在一名考勤负责人
    punch_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 考勤方式，0：考勤组人员可在任意地点、任意网络环境下打卡，1：GPS 打卡，2：Wi-Fi 打卡，4：考勤机打卡，8：IP 打卡。位运算，累加可支持多种考勤方式，比如，3：支持 GPS 打卡和 Wi-Fi 打卡，7：支持 GPS 打卡、Wi-Fi 打卡和考勤机打卡
    allow_out_punch: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否允许外勤打卡
    allow_pc_punch: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否允许 PC 端打卡
    allow_remedy: bool = attr.ib(default=None, metadata={"req_type": "json"})  # 是否允许补卡
    remedy_limit: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否限制补卡次数
    remedy_limit_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡次数
    remedy_period_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 补卡次数周期类型，0：自然月，1：自定义周期
    remedy_period_custom_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 补卡自定义周期每月起始日
    remedy_date_limit: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否限制补卡时间
    remedy_date_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡时间
    show_cumulative_time: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否展示上班累计时长
    show_over_time: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否展示加班累计时长
    hide_staff_punch_time: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否隐藏员工打卡具体时间
    face_punch: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否开启人脸识别打卡
    face_punch_cfg: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 人脸识别打卡规则，1：每次打卡均需人脸识别，2：疑似作弊打卡时需要人脸识别
    face_downgrade: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸识别失败时是否允许普通拍照打卡
    replace_basic_pic: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸识别失败时是否允许替换基准图片
    machines: typing.List[CreateUpdateAttendanceGroupReqGroupMachine] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 考勤机列表
    locations: typing.List[CreateUpdateAttendanceGroupReqGroupLocation] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 地址列表
    group_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 考勤类型，0：固定班制，2：排班制，3：自由班制
    punch_day_shift_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 固定班制必须填，长度必须等于7
    free_punch_cfg: CreateUpdateAttendanceGroupReqGroupFreePunchCfg = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 配置自由班制
    calendar_id: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 国家法定节假日历 ID，0：不根据国家法定节假日历排休，1：中国，2：美国，3：日本，4：印度，5：新加坡，默认为 1，必选字段
    need_punch_special_days: typing.List[
        CreateUpdateAttendanceGroupReqGroupNeedPunchSpecialDay
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 必须打卡的特殊日期
    no_need_punch_special_days: typing.List[
        CreateUpdateAttendanceGroupReqGroupNoNeedPunchSpecialDay
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 无需打卡的特殊日期
    effect_now: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否立即生效，默认为 false


@attr.s
class CreateUpdateAttendanceGroupReqEmployeeType(object):
    pass


@attr.s
class CreateUpdateAttendanceGroupReq(object):
    employee_type: CreateUpdateAttendanceGroupReqEmployeeType = attr.ib(
        factory=lambda: CreateUpdateAttendanceGroupReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 的类型，必选字段，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】
    dept_type: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 部门 ID 的类型，必选字段，可用值：【open_id（暂时只支持部门的 openid）】，示例值：“od-fcb45c28a45311afd441b8869541ece8”
    group: CreateUpdateAttendanceGroupReqGroup = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 考勤组


@attr.s
class CreateUpdateAttendanceGroupRespGroupNoNeedPunchSpecialDay(object):
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡日期，格式 20190101
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID


@attr.s
class CreateUpdateAttendanceGroupRespGroupNeedPunchSpecialDay(object):
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡日期，格式 20190101
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID


@attr.s
class CreateUpdateAttendanceGroupRespGroupFreePunchCfg(object):
    free_start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自由班制的打卡开始时间
    free_end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自由班制的打卡结束时间
    punch_day: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 打卡时间，格式 1111100
    work_day_no_punch_as_lack: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 工作日不打卡是否记为缺卡


@attr.s
class CreateUpdateAttendanceGroupRespGroupLocationLongitude(object):
    pass


@attr.s
class CreateUpdateAttendanceGroupRespGroupLocationLatitude(object):
    pass


@attr.s
class CreateUpdateAttendanceGroupRespGroupLocation(object):
    location_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址 ID
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址名称
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型，1：GPS，2：Wifi，8：IP
    latitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 地址纬度
    longitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 地址经度
    ssid: str = attr.ib(default="", metadata={"req_type": "json"})  # Wi-Fi 名称
    bssid: str = attr.ib(default="", metadata={"req_type": "json"})  # Wi-Fi 的 MAC 地址
    map_type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 地图类型，1：高德，2：谷歌
    address: str = attr.ib(default="", metadata={"req_type": "json"})  # 地址名称
    ip: str = attr.ib(default="", metadata={"req_type": "json"})  # IP 地址
    feature: str = attr.ib(default="", metadata={"req_type": "json"})  # 额外信息，例如运营商信息
    gps_range: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # GPS 打卡的有效范围（默认300m）


@attr.s
class CreateUpdateAttendanceGroupRespGroupMachine(object):
    machine_sn: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤机序列号
    machine_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤机名称


@attr.s
class CreateUpdateAttendanceGroupRespGroup(object):
    group_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 考勤组的 ID, 需要从获取用户打卡结果的接口中获取 groupId
    group_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 考勤组名称
    time_zone: str = attr.ib(default="", metadata={"req_type": "json"})  # 时区
    bind_dept_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 绑定的部门 ID
    except_dept_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 排除的部门 ID
    bind_user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 绑定的用户 ID
    except_user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 排除的用户 ID
    group_leader_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 考勤负责人 ID 列表，必选字段
    punch_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 考勤方式，0：考勤组人员可在任意地点、任意网络环境下打卡，1：GPS 打卡，2：Wi-Fi 打卡，4：考勤机打卡，8：IP 打卡。位运算，累加可支持多种考勤方式，比如，3：支持 GPS 打卡和 Wi-Fi 打卡，7：支持 GPS 打卡、Wi-Fi 打卡和考勤机打卡
    allow_out_punch: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否允许外勤打卡
    allow_pc_punch: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否允许 PC 端打卡
    allow_remedy: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否允许补卡
    remedy_limit: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否限制补卡次数
    remedy_limit_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡次数
    remedy_period_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 补卡次数周期类型，0：自然月，1：自定义周期
    remedy_period_custom_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 补卡自定义周期每月起始日
    remedy_date_limit: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否限制补卡时间
    remedy_date_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 补卡时间
    show_cumulative_time: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否展示上班累计时长
    show_over_time: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否展示加班累计时长
    hide_staff_punch_time: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否隐藏员工打卡具体时间
    face_punch: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否开启人脸识别打卡
    face_punch_cfg: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 人脸识别打卡规则，1：每次打卡均需人脸识别，2：疑似作弊打卡时需要人脸识别
    face_downgrade: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 人脸识别失败时是否允许普通拍照打卡
    replace_basic_pic: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 人脸识别失败时是否允许替换基准图片
    machines: typing.List[CreateUpdateAttendanceGroupRespGroupMachine] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 考勤机列表
    gps_range: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # GPS 打卡的有效范围（不建议使用）
    locations: typing.List[CreateUpdateAttendanceGroupRespGroupLocation] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 地址列表
    group_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 考勤类型，0：固定班制，2：排班制，3：自由班制
    punch_day_shift_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 固定班制必须填
    free_punch_cfg: CreateUpdateAttendanceGroupRespGroupFreePunchCfg = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 配置自由班制
    calendar_id: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 国家法定节假日历 ID，0：不根据国家法定节假日历排休，1：中国，2：美国，3：日本，4：印度，5：新加坡，默认为 1
    need_punch_special_days: typing.List[
        CreateUpdateAttendanceGroupRespGroupNeedPunchSpecialDay
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 必须打卡的特殊日期
    no_need_punch_special_days: typing.List[
        CreateUpdateAttendanceGroupRespGroupNoNeedPunchSpecialDay
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 无需打卡的特殊日期
    work_day_no_punch_as_lack: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 自由班制下工作日不打卡是否记为缺卡


@attr.s
class CreateUpdateAttendanceGroupResp(object):
    group: CreateUpdateAttendanceGroupRespGroup = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 考勤组


def _gen_create_update_attendance_group_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateUpdateAttendanceGroupResp,
        scope="Attendance",
        api="CreateUpdateAttendanceGroup",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/groups",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSheetFloatImageReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"
    float_image_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 浮动图片 id, 示例值："ye06SS14ph"


@attr.s
class DeleteSheetFloatImageResp(object):
    pass


def _gen_delete_sheet_float_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSheetFloatImageResp,
        scope="Drive",
        api="DeleteSheetFloatImage",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/float_images/:float_image_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class PrepareUploadDriveMediaReq(object):
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名, 示例值："test.txt", 最大长度：`250` 字符
    parent_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点类型, 示例值："doc_image", 可选值有: `doc_image`：docs图片, `sheet_image`：sheet图片, `doc_file`：doc文件, `sheet_file`：sheet文件, `vc_virtual_background`：vc虚拟背景(灰度中，暂未开放), `bitable_image`：bitable图片, `bitable_file`：bitable文件, `moments`：同事圈(灰度中，暂未开放), `ccm_import_open`：云文档导入文件
    parent_node: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点的标识符, 示例值："doccn123456675"
    size: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件大小, 示例值：1024, 最小值：`0`
    extra: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 扩展信息(可选), 示例值："{\"test\":\"test\"}"


@attr.s
class PrepareUploadDriveMediaResp(object):
    upload_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 分片上传事务ID
    block_size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分片大小策略
    block_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分片数量


def _gen_prepare_upload_drive_media_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=PrepareUploadDriveMediaResp,
        scope="Drive",
        api="PrepareUploadDriveMedia",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/medias/upload_prepare",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationMessageOverviewReqMessageType(object):
    pass


@attr.s
class GetApplicationMessageOverviewReqChatType(object):
    pass


@attr.s
class GetApplicationMessageOverviewReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 目标应用的 ID
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 起始时间戳（秒），时间跨度最长支持180天
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 截止时间戳（秒），时间跨度最长支持180天
    chat_type: GetApplicationMessageOverviewReqChatType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 聊天类型，大小写不敏感，p2p：私聊；group：群聊
    message_type: GetApplicationMessageOverviewReqMessageType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息类型，大小写不敏感，text：文本消息；image：图片消息；card：卡片消息；post：富文本消息；share_chat：群名片


@attr.s
class GetApplicationMessageOverviewRespGroupReadPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息已读用户数量


@attr.s
class GetApplicationMessageOverviewRespGroupRead(object):
    pv: GetApplicationMessageOverviewRespGroupReadPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息已读用户数量


@attr.s
class GetApplicationMessageOverviewRespGroupReceivedPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收群聊数量


@attr.s
class GetApplicationMessageOverviewRespGroupReceived(object):
    pv: GetApplicationMessageOverviewRespGroupReceivedPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息接收群聊数量


@attr.s
class GetApplicationMessageOverviewRespGroupSentPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收群聊数量


@attr.s
class GetApplicationMessageOverviewRespGroupSent(object):
    pv: GetApplicationMessageOverviewRespGroupSentPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息接收群聊数量


@attr.s
class GetApplicationMessageOverviewRespP2pReadPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息已读用户数量


@attr.s
class GetApplicationMessageOverviewRespP2pRead(object):
    pv: GetApplicationMessageOverviewRespP2pReadPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息已读用户数量


@attr.s
class GetApplicationMessageOverviewRespP2pReceivedPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收用户数量


@attr.s
class GetApplicationMessageOverviewRespP2pReceived(object):
    pv: GetApplicationMessageOverviewRespP2pReceivedPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息接收用户数量


@attr.s
class GetApplicationMessageOverviewRespP2pSentPv(object):
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 去重的消息接收用户数量


@attr.s
class GetApplicationMessageOverviewRespP2pSent(object):
    pv: GetApplicationMessageOverviewRespP2pSentPv = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息接收用户数量


@attr.s
class GetApplicationMessageOverviewResp(object):
    p2p_sent: GetApplicationMessageOverviewRespP2pSent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊发送
    p2p_received: GetApplicationMessageOverviewRespP2pReceived = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊接收
    p2p_read: GetApplicationMessageOverviewRespP2pRead = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单聊已读
    group_sent: GetApplicationMessageOverviewRespGroupSent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊发送
    group_received: GetApplicationMessageOverviewRespGroupReceived = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊接收
    group_read: GetApplicationMessageOverviewRespGroupRead = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群聊已读


def _gen_get_application_message_overview_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationMessageOverviewResp,
        scope="Application",
        api="GetApplicationMessageOverview",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v1/app_message_overview",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskFAQImageReq(object):
    id: str = attr.ib(default="", metadata={"req_type": "path"})  # 知识库ID, 示例值："12345"
    image_key: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 图像key, 示例值："img_b07ffac0-19c1-48a3-afca-599f8ea825fj"


@attr.s
class GetHelpdeskFAQImageRespFile(object):
    pass


@attr.s
class GetHelpdeskFAQImageResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


@attr.s
class GetHelpdeskFAQImageResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})
    code: int = attr.ib(default=0, metadata={"req_type": "json"})
    msg: str = attr.ib(default="", metadata={"req_type": "json"})
    data: GetHelpdeskFAQImageResp = attr.ib(default=None, metadata={"req_type": "json"})


def _gen_get_helpdesk_faq_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskFAQImageResp,
        scope="Helpdesk",
        api="GetHelpdeskFAQImage",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs/:id/image/:image_key",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveCommentListReqUserIDType(object):
    pass


@attr.s
class GetDriveCommentListReqFileType(object):
    pass


@attr.s
class GetDriveCommentListReq(object):
    file_type: GetDriveCommentListReqFileType = attr.ib(
        factory=lambda: GetDriveCommentListReqFileType(), metadata={"req_type": "query"}
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    user_id_type: GetDriveCommentListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    is_solved: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 是否已解决（可选）, 示例值：false
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："6916106822734578184"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnHh7U87HOFpii5u5G*****"


@attr.s
class GetDriveCommentListRespItemReplyListReplyContentElementPerson(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at联系人


@attr.s
class GetDriveCommentListRespItemReplyListReplyContentElementDocsLink(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at云文档


@attr.s
class GetDriveCommentListRespItemReplyListReplyContentElementTextRun(object):
    text: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 普通文本


@attr.s
class GetDriveCommentListRespItemReplyListReplyContentElement(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复的内容元素, 可选值有: `text_run`：普通文本, `docs_link`：at 云文档链接, `person`：at 联系人
    text_run: GetDriveCommentListRespItemReplyListReplyContentElementTextRun = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    docs_link: GetDriveCommentListRespItemReplyListReplyContentElementDocsLink = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 文本内容
    person: GetDriveCommentListRespItemReplyListReplyContentElementPerson = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容


@attr.s
class GetDriveCommentListRespItemReplyListReplyContent(object):
    elements: typing.List[
        GetDriveCommentListRespItemReplyListReplyContentElement
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复的内容


@attr.s
class GetDriveCommentListRespItemReplyListReply(object):
    reply_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    content: GetDriveCommentListRespItemReplyListReplyContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 回复内容


@attr.s
class GetDriveCommentListRespItemReplyList(object):
    replies: typing.List[GetDriveCommentListRespItemReplyListReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复列表


@attr.s
class GetDriveCommentListRespItem(object):
    comment_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 评论ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    is_solved: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否已解决
    solved_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 解决评论时间
    solver_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 解决评论者的用户ID
    reply_list: GetDriveCommentListRespItemReplyList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 评论里的回复列表


@attr.s
class GetDriveCommentListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetDriveCommentListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 评论列表


def _gen_get_drive_comment_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveCommentListResp,
        scope="Drive",
        api="GetDriveCommentList",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SendRawMessageReqMsgType(object):
    pass


@attr.s
class SendRawMessageReqReceiveIDType(object):
    pass


@attr.s
class SendRawMessageReq(object):
    receive_id_type: SendRawMessageReqReceiveIDType = attr.ib(
        factory=lambda: SendRawMessageReqReceiveIDType(), metadata={"req_type": "query"}
    )  # 消息接收者id类型 open_id/user_id/union_id/email/chat_id, 示例值："open_id", 可选值有: `open_id`：以open_id来识别用户, `user_id`：以user_id来识别用户, `union_id`：以union_id来识别用户, `email`：以email来识别用户, `chat_id`：以chat_id来识别群聊。可以调用接口 [搜索对用户或机器人可见的群列表](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat/search) 获取chat_id, 默认值: `open_id`
    receive_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 依据receive_id_type的值，填写对应的消息接收者id, 示例值："ou_7d8a6e6df7621556ce0d21922b676706ccs"
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息内容 json格式，格式说明参考: [发送消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/create_json), 示例值："{\"text\":\"<at user_id=\\\"ou_155184d1e73cbfb8973e5a9e698e74f2\\\">Tom</at> test content\"}"
    msg_type: SendRawMessageReqMsgType = attr.ib(
        factory=lambda: SendRawMessageReqMsgType(), metadata={"req_type": "json"}
    )  # 消息类型，包括：text、post、image、file、audio、media、sticker、interactive、share_chat、share_user, 示例值："text"


@attr.s
class SendRawMessageRespMentionIDType(object):
    pass


@attr.s
class SendRawMessageRespMention(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # mention key
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户open id
    id_type: SendRawMessageRespMentionIDType = attr.ib(
        factory=lambda: SendRawMessageRespMentionIDType(), metadata={"req_type": "json"}
    )  # id 可以是open_id，user_id或者union_id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 被at用户的姓名
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # tenant key


@attr.s
class SendRawMessageRespBody(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息jsonContent


@attr.s
class SendRawMessageRespSenderIDType(object):
    pass


@attr.s
class SendRawMessageRespSender(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的id
    id_type: SendRawMessageRespSenderIDType = attr.ib(
        factory=lambda: SendRawMessageRespSenderIDType(), metadata={"req_type": "json"}
    )  # 该字段标识发送者的id类型
    sender_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的类型
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # tenant key


@attr.s
class SendRawMessageRespMsgType(object):
    pass


@attr.s
class SendRawMessageResp(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息id open_message_id
    root_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 根消息id open_message_id
    parent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父消息的id open_message_id
    msg_type: SendRawMessageRespMsgType = attr.ib(
        factory=lambda: SendRawMessageRespMsgType(), metadata={"req_type": "json"}
    )  # 消息类型 text post card image等等
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息生成的时间戳(毫秒)
    update_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息更新的时间戳
    deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被撤回
    updated: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被更新
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 所属的群
    sender: SendRawMessageRespSender = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 发送者，可以是用户或应用
    body: SendRawMessageRespBody = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息内容，json结构，格式说明参考： [消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/events/message_content)
    mentions: typing.List[SendRawMessageRespMention] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被艾特的人或应用的id
    upper_message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上一层级的消息id open_message_id


def _gen_send_raw_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SendRawMessageResp,
        scope="Message",
        api="SendRawMessage",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/messages",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskTicketMessageListReq(object):
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 起始时间, 示例值：1617960686000
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 结束时间, 示例值：1617960687000
    page: int = attr.ib(default=0, metadata={"req_type": "query"})  # 页数ID, 示例值：1
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 消息数量，最大200，默认20, 示例值：10
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单ID, 示例值："6948728206392295444"


@attr.s
class GetHelpdeskTicketMessageListRespMessageMessageType(object):
    pass


@attr.s
class GetHelpdeskTicketMessageListRespMessage(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工单消息ID
    message_id: str = attr.ib(default="", metadata={"req_type": "json"})  # chat消息ID
    message_type: GetHelpdeskTicketMessageListRespMessageMessageType = attr.ib(
        factory=lambda: GetHelpdeskTicketMessageListRespMessageMessageType(),
        metadata={"req_type": "json"},
    )  # 消息类型；text：纯文本；post：富文本
    created_at: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 内容
    user_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户图片url
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户open ID


@attr.s
class GetHelpdeskTicketMessageListResp(object):
    messages: typing.List[GetHelpdeskTicketMessageListRespMessage] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单消息列表
    total: int = attr.ib(default=0, metadata={"req_type": "json"})  # 消息总数


def _gen_get_helpdesk_ticket_message_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskTicketMessageListResp,
        scope="Helpdesk",
        api="GetHelpdeskTicketMessageList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets/:ticket_id/messages",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class ResendAppTicketReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用唯一标识，创建应用后获得
    app_secret: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用秘钥，创建应用后获得


@attr.s
class ResendAppTicketResp(object):
    pass


def _gen_resend_app_ticket_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=ResendAppTicketResp,
        scope="Auth",
        api="ResendAppTicket",
        method="POST",
        url="https://open.feishu.cn/open-apis/auth/v3/app_ticket/resend/",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireJobProcessListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 不能超过 100, 示例值：10
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："1"


@attr.s
class GetHireJobProcessListRespItemStage(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 1=筛选型, 2=评估型, 3=笔试型, 4=面试型, 5=Offer型, 6=待入职, 7=已入职, 8=其它类型, 255=系统默认，后端模型中并没有该字段，仅用于前端显示,, 可选值有: `1`：筛选型, `2`：评估型, `3`：笔试型, `4`：面试型, `5`：Offer型, `6`：待入职, `7`：已入职, `8`：其它类型, `255`：系统默认


@attr.s
class GetHireJobProcessListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型 1=社招流程, 2=校招流程,, 可选值有: `1`：社招流程, `2`：校招流程
    stage_list: typing.List[GetHireJobProcessListRespItemStage] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 阶段列表, 内部按用户设置顺序排列


@attr.s
class GetHireJobProcessListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetHireJobProcessListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 列表


def _gen_get_hire_job_process_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireJobProcessListResp,
        scope="Hire",
        api="GetHireJobProcessList",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/job_processes",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_mail_mail_group_create import (
    CreateMailGroupReq,
    CreateMailGroupResp,
    _gen_create_mailgroup_req,
)
from pylark.api_service_mail_mail_group_get import (
    GetMailGroupReq,
    GetMailGroupResp,
    _gen_get_mailgroup_req,
)
from pylark.api_service_mail_mail_group_get_list import (
    GetMailGroupListReq,
    GetMailGroupListResp,
    _gen_get_mail_group_list_req,
)
from pylark.api_service_mail_mail_group_patch import (
    UpdateMailGroupPatchReq,
    UpdateMailGroupPatchResp,
    _gen_update_mail_group_patch_req,
)
from pylark.api_service_mail_mail_group_update import (
    UpdateMailGroupReq,
    UpdateMailGroupResp,
    _gen_update_mailgroup_req,
)
from pylark.api_service_mail_mail_group_delete import (
    DeleteMailGroupReq,
    DeleteMailGroupResp,
    _gen_delete_mailgroup_req,
)
from pylark.api_service_mail_mail_group_member_create import (
    CreateMailGroupMemberReq,
    CreateMailGroupMemberResp,
    _gen_create_mail_group_member_req,
)
from pylark.api_service_mail_mail_group_member_get import (
    GetMailGroupMemberReq,
    GetMailGroupMemberResp,
    _gen_get_mail_group_member_req,
)
from pylark.api_service_mail_mail_group_member_get_list import (
    GetMailGroupMemberListReq,
    GetMailGroupMemberListResp,
    _gen_get_mail_group_member_list_req,
)
from pylark.api_service_mail_mail_group_member_delete import (
    DeleteMailGroupMemberReq,
    DeleteMailGroupMemberResp,
    _gen_delete_mail_group_member_req,
)
from pylark.api_service_mail_mail_group_permission_member_create import (
    CreateMailGroupPermissionMemberReq,
    CreateMailGroupPermissionMemberResp,
    _gen_create_mail_group_permission_member_req,
)
from pylark.api_service_mail_mail_group_permission_member_get import (
    GetMailGroupPermissionMemberReq,
    GetMailGroupPermissionMemberResp,
    _gen_get_mail_group_permission_member_req,
)
from pylark.api_service_mail_mail_group_permission_member_get_list import (
    GetMailGroupPermissionMemberListReq,
    GetMailGroupPermissionMemberListResp,
    _gen_get_mail_group_permission_member_list_req,
)
from pylark.api_service_mail_mail_group_permission_member_delete import (
    DeleteMailGroupPermissionMemberReq,
    DeleteMailGroupPermissionMemberResp,
    _gen_delete_mail_group_permission_member_req,
)
from pylark.api_service_mail_public_mailbox_create import (
    CreatePublicMailboxReq,
    CreatePublicMailboxResp,
    _gen_create_public_mailbox_req,
)
from pylark.api_service_mail_public_mailbox_get import (
    GetPublicMailboxReq,
    GetPublicMailboxResp,
    _gen_get_public_mailbox_req,
)
from pylark.api_service_mail_public_mailbox_get_list import (
    GetPublicMailboxListReq,
    GetPublicMailboxListResp,
    _gen_get_public_mailbox_list_req,
)
from pylark.api_service_mail_public_mailbox_patch import (
    UpdatePublicMailboxPatchReq,
    UpdatePublicMailboxPatchResp,
    _gen_update_public_mailbox_patch_req,
)
from pylark.api_service_mail_public_mailbox_update import (
    UpdatePublicMailboxReq,
    UpdatePublicMailboxResp,
    _gen_update_public_mailbox_req,
)
from pylark.api_service_mail_public_mailbox_member_create import (
    CreatePublicMailboxMemberReq,
    CreatePublicMailboxMemberResp,
    _gen_create_public_mailbox_member_req,
)
from pylark.api_service_mail_public_mailbox_member_get import (
    GetPublicMailboxMemberReq,
    GetPublicMailboxMemberResp,
    _gen_get_public_mailbox_member_req,
)
from pylark.api_service_mail_public_mailbox_member_get_list import (
    GetPublicMailboxMemberListReq,
    GetPublicMailboxMemberListResp,
    _gen_get_public_mailbox_member_list_req,
)
from pylark.api_service_mail_public_mailbox_member_delete import (
    DeletePublicMailboxMemberReq,
    DeletePublicMailboxMemberResp,
    _gen_delete_public_mailbox_member_req,
)
from pylark.api_service_mail_public_mailbox_member_clear import (
    ClearPublicMailboxMemberReq,
    ClearPublicMailboxMemberResp,
    _gen_clear_public_mailbox_member_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkMailService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_mailgroup(
        self, request: CreateMailGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateMailGroupResp, Response]:
        return self.cli.raw_request(_gen_create_mailgroup_req(request, options))

    def get_mailgroup(
        self, request: GetMailGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMailGroupResp, Response]:
        return self.cli.raw_request(_gen_get_mailgroup_req(request, options))

    def get_mail_group_list(
        self, request: GetMailGroupListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMailGroupListResp, Response]:
        return self.cli.raw_request(_gen_get_mail_group_list_req(request, options))

    def update_mail_group_patch(
        self, request: UpdateMailGroupPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateMailGroupPatchResp, Response]:
        return self.cli.raw_request(_gen_update_mail_group_patch_req(request, options))

    def update_mailgroup(
        self, request: UpdateMailGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateMailGroupResp, Response]:
        return self.cli.raw_request(_gen_update_mailgroup_req(request, options))

    def delete_mailgroup(
        self, request: DeleteMailGroupReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteMailGroupResp, Response]:
        return self.cli.raw_request(_gen_delete_mailgroup_req(request, options))

    def create_mail_group_member(
        self, request: CreateMailGroupMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateMailGroupMemberResp, Response]:
        return self.cli.raw_request(_gen_create_mail_group_member_req(request, options))

    def get_mail_group_member(
        self, request: GetMailGroupMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMailGroupMemberResp, Response]:
        return self.cli.raw_request(_gen_get_mail_group_member_req(request, options))

    def get_mail_group_member_list(
        self, request: GetMailGroupMemberListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMailGroupMemberListResp, Response]:
        return self.cli.raw_request(
            _gen_get_mail_group_member_list_req(request, options)
        )

    def delete_mail_group_member(
        self, request: DeleteMailGroupMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteMailGroupMemberResp, Response]:
        return self.cli.raw_request(_gen_delete_mail_group_member_req(request, options))

    def create_mail_group_permission_member(
        self,
        request: CreateMailGroupPermissionMemberReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateMailGroupPermissionMemberResp, Response]:
        return self.cli.raw_request(
            _gen_create_mail_group_permission_member_req(request, options)
        )

    def get_mail_group_permission_member(
        self, request: GetMailGroupPermissionMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMailGroupPermissionMemberResp, Response]:
        return self.cli.raw_request(
            _gen_get_mail_group_permission_member_req(request, options)
        )

    def get_mail_group_permission_member_list(
        self,
        request: GetMailGroupPermissionMemberListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetMailGroupPermissionMemberListResp, Response]:
        return self.cli.raw_request(
            _gen_get_mail_group_permission_member_list_req(request, options)
        )

    def delete_mail_group_permission_member(
        self,
        request: DeleteMailGroupPermissionMemberReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[DeleteMailGroupPermissionMemberResp, Response]:
        return self.cli.raw_request(
            _gen_delete_mail_group_permission_member_req(request, options)
        )

    def create_public_mailbox(
        self, request: CreatePublicMailboxReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreatePublicMailboxResp, Response]:
        return self.cli.raw_request(_gen_create_public_mailbox_req(request, options))

    def get_public_mailbox(
        self, request: GetPublicMailboxReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetPublicMailboxResp, Response]:
        return self.cli.raw_request(_gen_get_public_mailbox_req(request, options))

    def get_public_mailbox_list(
        self, request: GetPublicMailboxListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetPublicMailboxListResp, Response]:
        return self.cli.raw_request(_gen_get_public_mailbox_list_req(request, options))

    def update_public_mailbox_patch(
        self, request: UpdatePublicMailboxPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdatePublicMailboxPatchResp, Response]:
        return self.cli.raw_request(
            _gen_update_public_mailbox_patch_req(request, options)
        )

    def update_public_mailbox(
        self, request: UpdatePublicMailboxReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdatePublicMailboxResp, Response]:
        return self.cli.raw_request(_gen_update_public_mailbox_req(request, options))

    def create_public_mailbox_member(
        self, request: CreatePublicMailboxMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreatePublicMailboxMemberResp, Response]:
        return self.cli.raw_request(
            _gen_create_public_mailbox_member_req(request, options)
        )

    def get_public_mailbox_member(
        self, request: GetPublicMailboxMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetPublicMailboxMemberResp, Response]:
        return self.cli.raw_request(
            _gen_get_public_mailbox_member_req(request, options)
        )

    def get_public_mailbox_member_list(
        self, request: GetPublicMailboxMemberListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetPublicMailboxMemberListResp, Response]:
        return self.cli.raw_request(
            _gen_get_public_mailbox_member_list_req(request, options)
        )

    def delete_public_mailbox_member(
        self, request: DeletePublicMailboxMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeletePublicMailboxMemberResp, Response]:
        return self.cli.raw_request(
            _gen_delete_public_mailbox_member_req(request, options)
        )

    def clear_public_mailbox_member(
        self, request: ClearPublicMailboxMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[ClearPublicMailboxMemberResp, Response]:
        return self.cli.raw_request(
            _gen_clear_public_mailbox_member_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireOfferSchemaReq(object):
    offer_schema_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # offer申请表的ID *必需属性, 示例值："1231231231231"


@attr.s
class GetHireOfferSchemaRespObjectOptionName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireOfferSchemaRespObjectOption(object):
    name: GetHireOfferSchemaRespObjectOptionName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 名字
    index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 选项序号
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 选项当前是否启用, 可选值有: `1`：进行中, `2`：已终止


@attr.s
class GetHireOfferSchemaRespObjectName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetHireOfferSchemaRespObject(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段ID
    name: GetHireOfferSchemaRespObjectName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段名称
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段类型, text=单行文本, long_text=多行文本, select=单选, multi_select=多选, date_select=日期, number=数字
    is_customized: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 字段是否为自定义
    option_list: typing.List[GetHireOfferSchemaRespObjectOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 单选/多选可选择字段的选项值


@attr.s
class GetHireOfferSchemaResp(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # offer申请表ID
    scenario: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # offer申请表使用场景, 可选值有: `1`：Offer审批表
    version: int = attr.ib(default=0, metadata={"req_type": "json"})  # 申请表版本
    object_list: typing.List[GetHireOfferSchemaRespObject] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 字段对象信息


def _gen_get_hire_offer_schema_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireOfferSchemaResp,
        scope="Hire",
        api="GetHireOfferSchema",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/offer_schemas/:offer_schema_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# coding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

from enum import Enum


class DepartmentIDType(Enum):
    """ID类型"""

    department_id = "department_id"  # 以 department_id 来识别
    open_department_id = "open_department_id"  # open_department_id



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SetVCRoomConfigReqRoomConfigDigitalSignageMaterial(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 素材ID, 示例值："7847784676276"
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材名称, 示例值："name"
    material_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 素材类型, 示例值：0, 可选值有: `1`：图片, `2`：视频, `3`：GIF
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材url, 示例值："url"
    duration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 播放时长（单位sec）, 示例值：15
    cover: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 素材封面url, 示例值："url"
    md5: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材文件md5, 示例值："md5"


@attr.s
class SetVCRoomConfigReqRoomConfigDigitalSignage(object):
    enable: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否开启数字标牌功能, 示例值：true
    mute: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否静音播放, 示例值：true
    start_display: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程会议开始前n分钟结束播放, 示例值：3
    stop_display: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 会议结束后n分钟开始播放, 示例值：3
    materials: typing.List[
        SetVCRoomConfigReqRoomConfigDigitalSignageMaterial
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 素材列表


@attr.s
class SetVCRoomConfigReqRoomConfig(object):
    room_background: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 飞书会议室背景图, 示例值："https://lf1-ttcdn-tos.pstatp.com/obj/xxx"
    display_background: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 飞书签到板背景图, 示例值："https://lf1-ttcdn-tos.pstatp.com/obj/xxx"
    digital_signage: SetVCRoomConfigReqRoomConfigDigitalSignage = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 飞书会议室数字标牌


@attr.s
class SetVCRoomConfigReq(object):
    scope: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 设置节点范围, 示例值：5, 可选值有: `1`：租户, `2`：国家/地区, `3`：城市, `4`：建筑, `5`：楼层, `6`：会议室
    country_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 国家/地区ID scope为2，3时需要此参数, 示例值："086"
    district_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 城市ID scope为3时需要此参数, 示例值："223"
    building_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 建筑ID scope为4，5时需要此参数, 示例值："66"
    floor_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 楼层 scope为5时需要此参数, 示例值："3"
    room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议室ID scope为6时需要此参数, 示例值："67687262867363"
    room_config: SetVCRoomConfigReqRoomConfig = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议室设置


@attr.s
class SetVCRoomConfigResp(object):
    pass


def _gen_set_vc_room_config_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SetVCRoomConfigResp,
        scope="VC",
        api="SetVCRoomConfig",
        method="POST",
        url="https://open.feishu.cn/open-apis/vc/v1/room_configs/set",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CancelApprovalInstanceReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义Code
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例Code
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 操作用户
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 撤回的实例的时候可以添加评论
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 某个应用下用户的唯一标识，根据userID、openID、TenantId获得Lark用户。
    notify_starter: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 如果为true，撤回实例的时候会收到一条消息提醒。


@attr.s
class CancelApprovalInstanceResp(object):
    pass


def _gen_cancel_approval_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CancelApprovalInstanceResp,
        scope="Approval",
        api="CancelApprovalInstance",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/cancel",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMailGroupReq(object):
    mailgroup_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 邮件组ID或者邮件组地址, 示例值："xxxxxxxxxxxxxxx 或 test_mail_group@xxx.xx"


@attr.s
class GetMailGroupResp(object):
    mailgroup_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮件组ID
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮件组地址
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮件组名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮件组描述
    direct_members_count: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 邮件组成员数量
    include_external_member: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否包含外部成员
    include_all_company_member: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否是全员邮件组
    who_can_send_mail: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 谁可发送邮件到此邮件组, 可选值有: `ANYONE`：任何人, `ALL_INTERNAL_USERS`：仅组织内部成员, `ALL_GROUP_MEMBERS`：仅邮件组成员, `CUSTOM_MEMBERS`：自定义成员


def _gen_get_mailgroup_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMailGroupResp,
        scope="Mail",
        api="GetMailGroup",
        method="GET",
        url="https://open.feishu.cn/open-apis/mail/v1/mailgroups/:mailgroup_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetOKRPeriodListReq(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标志page_token, 示例值："xaasdasdax"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小，默认10, 示例值：10, 默认值: `10`


@attr.s
class GetOKRPeriodListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # id
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 启用状态, 可选值有: `0`：正常状态, `1`：暂不处理, `2`：标记失效, `3`：隐藏周期


@attr.s
class GetOKRPeriodListResp(object):
    page_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 分页标志
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否有更多
    items: typing.List[GetOKRPeriodListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据项


def _gen_get_okr_period_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetOKRPeriodListResp,
        scope="OKR",
        api="GetOKRPeriodList",
        method="GET",
        url="https://open.feishu.cn/open-apis/okr/v1/periods",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadDriveMediaReqFile(object):
    pass


@attr.s
class UploadDriveMediaReq(object):
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名, 示例值："test.txt", 最大长度：`250` 字符
    parent_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点类型, 示例值："doc_image", 可选值有: `doc_image`：docs图片, `sheet_image`：sheet图片, `doc_file`：doc文件, `sheet_file`：sheet文件, `vc_virtual_background`：vc虚拟背景(灰度中，暂未开放), `bitable_image`：bitable图片, `bitable_file`：bitable文件, `moments`：同事圈(灰度中，暂未开放), `ccm_import_open`：云文档导入文件
    parent_node: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点的token, 示例值："doccn123456"
    size: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件大小,全量上传最大20M, 示例值：1024, 最大值：`20971520`
    checksum: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件adler32校验和(可选), 示例值："12345678"
    extra: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 扩展信息(可选), 示例值："{"test":"test"}"
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件内容, 示例值：file binary


@attr.s
class UploadDriveMediaResp(object):
    file_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文件的 token


def _gen_upload_drive_media_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadDriveMediaResp,
        scope="Drive",
        api="UploadDriveMedia",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/medias/upload_all",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveDocMetaReq(object):
    doc_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # doc 的 token，获取方式见[准备接入文档 API](https://open.feishu.cn/document/ukTMukTMukTM/ugzNzUjL4czM14CO3MTN/guide/getting-start)


@attr.s
class GetDriveDocMetaResp(object):
    create_date: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建日期
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间戳
    creator: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建者open_id
    create_user_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建者用户名
    delete_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 删除标志，0表示正常访问未删除，1表示在回收站，2表示已经彻底删除
    edit_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 最后编辑时间戳
    edit_user_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 最后编辑者用户名
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否外部文档
    is_pined: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否在接口调用者目录里快速访问
    is_stared: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否在接口调用者目录里收藏
    obj_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档类型，固定是doc
    owner: str = attr.ib(default="", metadata={"req_type": "json"})  # 当前所有者open_id
    owner_user_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 当前所有者用户名
    server_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 处理请求时的服务器时间戳
    tenant_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档所在租户id
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档名称
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 文档类型，固定是2
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档url


def _gen_get_drive_doc_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveDocMetaResp,
        scope="Drive",
        api="GetDriveDocMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/doc/v2/meta/:docToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireApplicationListReq(object):
    process_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 按流程过滤, 示例值："212121"
    stage_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 按阶段过滤, 示例值："212121"
    talent_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 按人才过滤, 示例值："123321"
    active_status: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 按活跃状态筛选 1=活跃投递, 2=非活跃投递, 3=全部,, 示例值："1"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 查询游标, 由上一页结果返回, 第一页不传, 示例值："1"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 每页限制, 每页最大不超过100, 示例值：100


@attr.s
class GetHireApplicationListResp(object):
    items: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 投递数据列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 游标, 翻下一页数据时使用
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有下一页数据


def _gen_get_hire_application_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireApplicationListResp,
        scope="Hire",
        api="GetHireApplicationList",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/applications",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



import logging
from typing import TypeVar, Type, TYPE_CHECKING, Tuple
import attr
import requests

from pylark.helper import _make_dataclass_from_dict, _to_attr_dict
from pylark.lark_exception import PyLarkError
from pylark.log import logger

if TYPE_CHECKING:
    from pylark import Lark

RawRequestDataClass = TypeVar("RawRequestDataClass")


@attr.s
class Response(object):
    method = attr.ib(default="")
    url = attr.ib(default="")
    header = attr.ib(factory=lambda: dict())
    status_code = attr.ib(default=0)
    request_id = attr.ib(default="")
    content_length = attr.ib(default=0)


@attr.s
class MethodOption(object):
    user_access_token = attr.ib(default="")


# type MethodOptionFunc func(*MethodOption)


def _new_method_option(options=None) -> MethodOption:
    return MethodOption()


@attr.s
class RawRequestReq(object):
    scope = attr.ib(default="")
    api = attr.ib(default="")
    method = attr.ib(default="")
    url = attr.ib(default="")
    body = attr.ib(default=None)
    is_file = attr.ib(default=False)
    need_tenant_access_token = attr.ib(default=False)
    need_app_access_token = attr.ib(default=False)
    need_user_access_token = attr.ib(default=False)
    need_helpdesk_access_token = attr.ib(default=False)
    need_helpdesk_auth = attr.ib(default=False)
    method_option: MethodOption = attr.ib(factory=lambda: MethodOption())
    headers: dict = attr.ib(factory=lambda: dict())
    dataclass: Type[RawRequestDataClass] = attr.ib(default=None)


class Request(object):
    @staticmethod
    def raw_request(
        cli: "Lark", req: RawRequestReq
    ) -> Tuple[RawRequestDataClass, Response]:
        req.headers = Request._prepare_headers(cli, req)

        data, response = Request.do_request(req)

        if not req.dataclass:
            return data, response

        return _make_dataclass_from_dict(req.dataclass, data), response

    @staticmethod
    def _prepare_headers(cli: "Lark", req: RawRequestReq) -> dict:
        headers = {}
        if req.method != "GET":
            headers["Content-Type"] = "application/json; charset=utf-8"

        if req.need_user_access_token and req.method_option.user_access_token != "":
            headers["Authorization"] = "Bearer " + req.method_option.user_access_token
        elif req.need_tenant_access_token:
            res, _ = cli.auth.get_tenant_access_token()
            headers["Authorization"] = "Bearer " + res.token
        elif req.need_app_access_token:
            res, _ = cli.auth.get_app_access_token()
            headers["Authorization"] = "Bearer " + res.token

        if req.need_helpdesk_access_token:
            headers[
                "X-Lark-Helpdesk-Authorization"
            ] = ""  # base64.StdEncoding.EncodeToString([]byte(r.helpdeskID + ":" + r.helpdeskToken))

        return headers

    @staticmethod
    def do_request(request_parm: RawRequestReq) -> Tuple[dict, Response]:
        response = Response()
        real_req = Request._parse_request_param(request_parm)

        query = real_req["query"]
        body = real_req["body"]
        header = real_req["header"]
        method = real_req["method"]
        url = real_req["url"]

        response.method = method
        response.url = url

        logger.debug(
            "[lark] request %s#%s, %s %s, header=%s, body=%s",
            request_parm.scope,
            request_parm.api,
            method,
            url,
            header,
            body,
        )

        body = _to_attr_dict(body)

        r = requests.request(
            response.method,
            response.url,
            json=body,
            headers=header,
            params=query,
        )
        resp_body = r.json()
        response.request_id = r.headers.get("X-Request-Id")

        logger.debug(
            "[lark] request %s#%s, request_id=%s, response=%s",
            request_parm.scope,
            request_parm.api,
            response.request_id,
            resp_body,
        )

        # r.raise_for_status()

        # 	response.StatusCode = resp.StatusCode
        # 	response.RequestID = resp.Header.Get("X-Request-Id")
        # 	response.Header = resp.Header
        # 	response.ContentLength = resp.ContentLength

        code = resp_body.get("code") or 0
        msg = resp_body.get("msg") or ""
        if "data" in resp_body:
            data = resp_body.get("data") or {}
        else:
            data = resp_body
        if code != 0:
            raise PyLarkError(
                scope=request_parm.scope, func=request_parm.method, code=code, msg=msg
            )

        return data, response

    @staticmethod
    def _parse_request_param(req: RawRequestReq):
        file_key = ""
        body = {}
        query = {}
        uri = req.url
        headers = req.headers
        if not headers:
            headers = {}

        if isinstance(req.body, dict):
            body = req.body
        else:
            for field in attr.fields(type(req.body)):
                req_type = field.metadata["req_type"]
                if req_type == "json":
                    field_val = getattr(req.body, field.name, None)
                    if field_val:
                        body[field.name] = getattr(req.body, field.name)
                elif req_type == "query":
                    field_val = getattr(req.body, field.name, None)
                    if field_val:
                        query[field.name] = getattr(req.body, field.name)
                else:
                    field_val = getattr(req.body, field.name, None)
                    if field_val:
                        uri = uri.replace(":" + field.name, field_val)

        return {
            "query": query,
            "body": body,
            "method": req.method,
            "url": uri,
            "header": headers,
        }



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteUserReqUserIDType(object):
    pass


@attr.s
class DeleteUserReq(object):
    user_id_type: DeleteUserReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    user_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 用户ID，需要与查询参数中的user_id_type类型保持一致。, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    department_chat_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门群接收者。被删除用户为部门群群主时，转让群主给指定接收者，不指定接收者则默认转让给群内第一个入群的人, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    external_chat_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 外部群接收者。被删除用户为外部群群主时，转让群主给指定接收者，不指定接收者则默认转让给群内与被删除用户在同一组织的第一个入群的人，如果组织内只有该用户在群里，则解散外部群, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    docs_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档接收者。用户被删除时，其拥有的文档转让给接收者，不指定接收者则默认转让给直接领导，如果无直接领导则直接删除文档资源, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    calendar_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程接收者。用户被删除时，其拥有的日程转让给接收者，不指定接收者则默认转让给直接领导，如果无直接领导则直接删除日程资源, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    application_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 应用接收者。用户被删除时，其创建的应用转让给接收者，不指定接收者则默认转让给直接领导，如果无直接领导则不会转移应用，会造成应用不可用, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    helpdesk_acceptor_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户超文本帮助信息接收者, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"


@attr.s
class DeleteUserResp(object):
    pass


def _gen_delete_user_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteUserResp,
        scope="Contact",
        api="DeleteUser",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/contact/v3/users/:user_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
